summaryrefslogtreecommitdiffstats
path: root/libkmime/kmime_headers.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkmime/kmime_headers.h')
-rw-r--r--libkmime/kmime_headers.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/libkmime/kmime_headers.h b/libkmime/kmime_headers.h
index 69f139a5..45825864 100644
--- a/libkmime/kmime_headers.h
+++ b/libkmime/kmime_headers.h
@@ -116,16 +116,16 @@ class KDE_EXPORT Base {
/** Create an empty header. */
Base() : e_ncCS(0), p_arent(0) {}
- /** Create an empty header with a tqparent-content. */
- Base(KMime::Content *tqparent) : e_ncCS(0), p_arent(tqparent) {}
+ /** Create an empty header with a parent-content. */
+ Base(KMime::Content *parent) : e_ncCS(0), p_arent(parent) {}
/** Destructor */
virtual ~Base() {}
- /** Return the tqparent of this header. */
- KMime::Content* tqparent() { return p_arent; }
+ /** Return the parent of this header. */
+ KMime::Content* parent() { return p_arent; }
- /** Set the tqparent for this header. */
+ /** Set the parent for this header. */
void setParent(KMime::Content *p) { p_arent=p; }
/** Parse the given string. Take care of RFC2047-encoded